# Facebook Report

Pequeño programa para generar un documento .docx con datos relevantes para juzgar el desempeño de una cuenta de empresa de Instagram (requiere estar asociada a una fanpage de Facebook).

## Uso

El programa requiere entregar un token de acceso a la fanpage de Facebook asociada a la cuenta de Instagram. Para ello es necesario crear una cuenta en Facebook for developers (http://developers.facebook.com).

